pyMagnum
========

pyMagnum is a Python 3 implementation of a read only interface to the
Magnum Energy network.

This software is not endorsed or supported by Magnum Energy, a product
of Sensata Technologies https://www.magnum-dimensions.com/

`Documentation <https://pymagnum.readthedocs.io/>`_

`Changes <https://github.com/CharlesGodwin/pymagnum/blob/master/CHANGES.rst>`_

Copyright (c) 2018-2019 Charles Godwin magnum@godwin.ca

SPDX-License-Identifier: BSD-3-Clause
